Gordon Janitor's Plugin System
==============================

.. automodule:: gordon.plugins_loader
    :noindex:

Writing a Plugin
----------------
.. todo::

    Add documentation once interfaces are firmed up
